summaryrefslogtreecommitdiffstats
path: root/krita/ui/squeezedcombobox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /krita/ui/squeezedcombobox.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krita/ui/squeezedcombobox.h')
-rw-r--r--krita/ui/squeezedcombobox.h59
1 files changed, 30 insertions, 29 deletions
diff --git a/krita/ui/squeezedcombobox.h b/krita/ui/squeezedcombobox.h
index 51f9eb51..66758335 100644
--- a/krita/ui/squeezedcombobox.h
+++ b/krita/ui/squeezedcombobox.h
@@ -20,15 +20,15 @@
/** @file squeezedcombobox.h */
-#ifndef SQUEEZEDCOMBOBOX_H
-#define SQUEEZEDCOMBOBOX_H
+#ifndef STQUEEZEDCOMBOBOX_H
+#define STQUEEZEDCOMBOBOX_H
-class QTimer;
+class TQTimer;
-// Qt includes.
+// TQt includes.
-#include <qcombobox.h>
-#include <qtooltip.h>
+#include <tqcombobox.h>
+#include <tqtooltip.h>
class SqueezedComboBox;
@@ -37,11 +37,11 @@ class SqueezedComboBox;
* the tooltip will contain the full text and helps
* the user find the correct entry. It is automatically
* activated when starting a SqueezedComboBox. This is
* inherited from QToolTip
*
* @author Tom Albers
*/
-class SqueezedComboBoxTip : public QToolTip
+class SqueezedComboBoxTip : public TQToolTip
{
public:
/**
@@ -51,18 +51,18 @@ public:
* t = new SqueezedComboBoxTip( this->listBox()->viewport(), this );
* @endcode
*
* @param parent parent widget (viewport)
* @param name parent widget
*/
- SqueezedComboBoxTip( QWidget *parent, SqueezedComboBox *name );
+ SqueezedComboBoxTip( TQWidget *tqparent, SqueezedComboBox *name );
protected:
/**
* Reimplemented version from QToolTip which shows the
* tooltip when needed.
* @param pos the point where the mouse currently is
*/
- void maybeTip( const QPoint& pos );
+ void maybeTip( const TQPoint& pos );
private:
SqueezedComboBox* m_originalWidget;
@@ -70,7 +70,7 @@ private:
/** @class SqueezedComboBox
*
* This widget is a QComboBox, but then a little bit
* different. It only shows the right part of the items
* depending on de size of the widget. When it is not
* possible to show the complete item, it will be shortened
@@ -79,58 +79,59 @@ private:
* @image html squeezedcombobox.png "This is how it looks"
* @author Tom Albers
*/
-class SqueezedComboBox : public QComboBox
+class SqueezedComboBox : public TQComboBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent parent widget
* @param name name to give to the widget
*/
- SqueezedComboBox(QWidget *parent = 0, const char *name = 0 );
+ SqueezedComboBox(TQWidget *tqparent = 0, const char *name = 0 );
/**
* destructor
*/
virtual ~SqueezedComboBox();
- bool contains(const QString & text) const;
+ bool tqcontains(const TQString & text) const;
/**
* This inserts a item to the list. See QComboBox::insertItem()
* for detaills. Please do not use QComboBox::insertItem() to this
* widget, as that will fail.
* @param newItem the original (long version) of the item which needs
* to be added to the combobox
* @param index the position in the widget.
*/
- void insertSqueezedItem(const QString& newItem, int index);
+ void insertSqueezedItem(const TQString& newItem, int index);
/**
* This method returns the full text (not squeezed) of the currently
* highlighted item.
* @return full text of the highlighted item
*/
- QString itemHighlighted( );
+ TQString itemHighlighted( );
/**
* Sets the sizeHint() of this widget.
*/
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
private slots:
void slotTimeOut();
void slotUpdateToolTip( int index );
private:
- void resizeEvent ( QResizeEvent * );
- QString squeezeText( const QString& original);
+ void resizeEvent ( TQResizeEvent * );
+ TQString squeezeText( const TQString& original);
- QMap<int,QString> m_originalItems;
- QTimer* m_timer;
+ TQMap<int,TQString> m_originalItems;
+ TQTimer* m_timer;
SqueezedComboBoxTip* m_tooltip;
};
-#endif // SQUEEZEDCOMBOBOX_H
+#endif // STQUEEZEDCOMBOBOX_H
@@ -37,11 +37,11 @@ class SqueezedComboBox;
* the user find the correct entry. It is automatically
* activated when starting a SqueezedComboBox. This is
- * inherited from QToolTip
+ * inherited from TQToolTip
*
* @author Tom Albers
@@ -51,18 +51,18 @@ public:
* @endcode
*
- * @param parent parent widget (viewport)
- * @param name parent widget
+ * @param tqparent tqparent widget (viewport)
+ * @param name tqparent widget
*/
@@ -51,18 +51,18 @@ public:
protected:
/**
- * Reimplemented version from QToolTip which shows the
+ * Reimplemented version from TQToolTip which shows the
* tooltip when needed.
* @param pos the point where the mouse currently is
@@ -70,7 +70,7 @@ private:
/** @class SqueezedComboBox
*
- * This widget is a QComboBox, but then a little bit
+ * This widget is a TQComboBox, but then a little bit
* different. It only shows the right part of the items
* depending on de size of the widget. When it is not
@@ -79,58 +79,59 @@ private:
/**
* Constructor
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param name name to give to the widget
*/
@@ -79,58 +79,59 @@ private:
/**
- * This inserts a item to the list. See QComboBox::insertItem()
- * for detaills. Please do not use QComboBox::insertItem() to this
+ * This inserts a item to the list. See TQComboBox::insertItem()
+ * for detaills. Please do not use TQComboBox::insertItem() to this
* widget, as that will fail.
* @param newItem the original (long version) of the item which needs
@@ -79,58 +79,59 @@ private:
/**
- * Sets the sizeHint() of this widget.
+ * Sets the tqsizeHint() of this widget.
*/